module Fl.Window  where


import Foreign
import Foreign.C
import Fl.Widget

data F_Window = F_Window ()

data WindowPtr = WindowPtr (ForeignPtr F_Window)

foreign import ccall f_newWindow :: Int -> Int -> IO (Ptr F_Window)
foreign import ccall f_deleteWindow :: (Ptr F_Window) -> IO ()
foreign import ccall f_Window_memfn_end :: (Ptr F_Window) -> IO ()
foreign import ccall f_Window_memfn_show :: (Ptr F_Window) -> IO ()
foreign import ccall f_Window_memfn_add :: (Ptr F_Window) -> (Ptr F_Widget) -> IO ()
foreign import ccall f_Window_removeChildren :: (Ptr F_Window) -> IO ()
foreign import ccall f_Window_memfn_visible :: (Ptr F_Window) -> IO (Bool)
foreign import ccall f_Window_memfn_hide :: (Ptr F_Window) -> IO ()

newWindow :: Int -> Int -> IO WindowPtr
newWindow a b = do
  it <- f_newWindow a b
  fptr <- newForeignPtr it (f_deleteWindow it)
  return (WindowPtr fptr)

window_memfun_end a = do
  let WindowPtr  b = a
  f_Window_memfn_end $ foreignPtrToPtr b
  touchForeignPtr b
  return ()

window_memfun_show a = do
  let WindowPtr  b = a
  f_Window_memfn_show $ foreignPtrToPtr b
  touchForeignPtr b
  return ()

window_memfn_add (WindowPtr b) (WidgetPtr child) = do 
  f_Window_memfn_add (foreignPtrToPtr b)  (foreignPtrToPtr child)
  touchForeignPtr b
  touchForeignPtr child
  return ()

window_removeChildren a = do 
  let WindowPtr  b = a
  f_Window_removeChildren $ foreignPtrToPtr b 
  touchForeignPtr b
  return ()

window_memfun_hide (WindowPtr b) = do 
  f_Window_memfn_hide $ foreignPtrToPtr b 
  touchForeignPtr b
  return ()

window_memfun_visible (WindowPtr b) = do 
  ret <- f_Window_memfn_visible $ foreignPtrToPtr b 
  touchForeignPtr b
  return (ret)

window_to_Widget :: WindowPtr -> IO( WidgetPtr )
window_to_Widget (WindowPtr b) =
  return $ newWidgetPtr (castForeignPtr b)
